==> GeneSpring_1.0.1.tar.gz: GeneSpring/R/GSint.R <==
######################################################################################################
#
# GSint CLASS definition
#
# this is the GSint class definition for the GeneSpring Interpretation class
#  and includes a constructor fucntion GSint()
#
#
#
# SLOTS
# -----
# expName:  Experiment name
# a.nor:    Matrix representing the AVERAGE expression values for the NORMALIZED expression values
# se.nor:   Matrix representing the STANDARD ERROR for the NORMALIZED expression values
# sd.nor:   Matrix representing the STANDARD DEVIATION for the NORMALIZED expression values
# n.nor:    Matrix representing the NUMBER OF REPLICATES in this condition for the NORMALIZED values
# a.raw:    Matrix representing the AVERAGE expression values for the RAW expression values
# se.raw:   Matrix representing the STANDARD ERROR for the NORMALIZED expression values
# sd.raw:   Matrix representing the STANDARD DEVIATION for the NORMALIZED expression values
# n.raw:    Matrix representing the NUMBER OF REPLICATES in this condition for the NORMALIZED values
# a.ctr:    Matrix representing the AVERAGE expression values for the RAW expression values
# se.ctr:   Matrix representing the STANDARD ERROR for the NORMALIZED expression values
# sd.ctr:   Matrix representing the STANDARD DEVIATION for the NORMALIZED expression values
# n.ctr:    Matrix representing the NUMBER OF REPLICATES in this condition for the NORMALIZED values
# expparam: Data drame representin the sample attributes or experimental parameters
# numConditions: numeric value representing the number of conditions in this experiment
# ngenes:   Numeric values representing the number of conditions in this experiment
#
######################################################################################################

library(methods)

setClass("GSint",
    representation(
        expName = "character",
        a.nor = "matrix",
        se.nor = "matrix",
        sd.nor = "matrix",
        n.nor = "matrix",
        a.raw = "matrix",
        se.raw = "matrix",
        sd.raw = "matrix",
        n.raw = "matrix",
        a.ctr = "matrix",
        se.ctr = "matrix",
        sd.ctr = "matrix",
        n.ctr = "matrix",
        expparam = "data.frame",
        numConditions = "numeric",
        ngenes = "numeric"
    ),
    prototype(
        expName = "GeneSpring experiment",
        a.nor = matrix(nc=0,nr=0),
        se.nor = matrix(nc=0,nr=0),
        sd.nor = matrix(nc=0,nr=0),
        n.nor = matrix(nc=0,nr=0),
        a.raw = matrix(nc=0,nr=0),
        se.raw = matrix(nc=0,nr=0),
        sd.raw = matrix(nc=0,nr=0),
        n.raw = matrix(nc=0,nr=0),
        a.ctr = matrix(nc=0,nr=0),
        se.ctr = matrix(nc=0,nr=0),
        sd.ctr = matrix(nc=0,nr=0),
        n.ctr = matrix(nc=0,nr=0),
        expparam = data.frame(),
        numConditions = 0,
        ngenes = 0
    )
)


"GSint" <-
function(
             expName = "GeneSpring experiment",
             a.nor = matrix(nc=0,nr=0),
             se.nor = matrix(nc=0,nr=0),
             sd.nor = matrix(nc=0,nr=0),
             n.nor = matrix(nc=0,nr=0),
             a.raw = matrix(nc=0,nr=0),
             se.raw = matrix(nc=0,nr=0),
             sd.raw = matrix(nc=0,nr=0),
             n.raw = matrix(nc=0,nr=0),
             a.ctr = matrix(nc=0,nr=0),
             se.ctr = matrix(nc=0,nr=0),
             sd.ctr = matrix(nc=0,nr=0),
             n.ctr = matrix(nc=0,nr=0),
             expparam = data.frame(),
             numConditions = 0,
             ngenes = 0
         ) {
         
         if(numConditions == 0) numConditions<-dim(expparam)[2]
         if(ngenes == 0) ngenes<-max(dim(a.nor)[1],dim(se.nor)[1],dim(sd.nor)[1],dim(se.nor)[1],dim(n.nor)[1],dim(a.raw)[1],dim(se.raw)[1],dim(sd.nor)[1],dim(n.nor)[1],dim(a.ctr)[1],dim(se.ctr)[1],dim(n.ctr)[1])

         library(methods)

         new("GSint",
             expName = expName,
             a.nor = as.matrix(a.nor),
             se.nor = as.matrix(se.nor),
             sd.nor = as.matrix(sd.nor),
             n.nor = as.matrix(n.nor),
             a.raw = as.matrix(a.raw),
             se.raw = as.matrix(se.raw),
             sd.raw = as.matrix(sd.raw),
             n.raw = as.matrix(n.raw),
             a.ctr = as.matrix(a.ctr),
             se.ctr = as.matrix(se.ctr),
             sd.ctr = as.matrix(sd.ctr),
             n.ctr = as.matrix(n.ctr),
             expparam = as.data.frame(expparam),
             numConditions = as.numeric(numConditions),
             ngenes = as.numeric(ngenes)
         )
}

setMethod("show", "GSint",
    function(object ) {
        cat("GeneSpring Expression Interpretation set (GSint)\n\t","\"",object@expName,"\" (slot: expName)\n\twith ",
             object@ngenes," genes (slot: ngenes),\n\t",object@numConditions,
             " Conditions/samples (slot: numConditions)\n\tand ",
             dim(object@expparam)[1]," experimental parameters.\n",sep="")
        cat("Available expression data slots:\n")
        if(length(object@a.nor) != 0) {
           cat("\ta.nor\t(Normalized expression values).\n")
        }
        if(length(object@sd.nor) != 0) {
           cat("\tsd.nor\t(Standard Deviation on Normalized expression values).\n")
        }
        if(length(object@se.nor) != 0) {
           cat("\tse.nor\t(Standard Error on Normalized expression values).\n")
        }
        if(length(object@n.nor) != 0) {
           cat("\tn.nor\t(Number of replicates in Normalized expression values).\n")
        }
        if(length(object@a.raw) != 0) {
           cat("\ta.raw\t(Raw expression values).\n")
        }
        if(length(object@sd.raw) != 0) {
           cat("\tsd.raw\t(Standard Deviation on Raw expression values).\n")
        }
        if(length(object@se.raw) != 0) {
           cat("\tse.raw\t(Standard Error on Raw expression values).\n")
        }
        if(length(object@n.raw) != 0) {
           cat("\tn.raw\t(Number of replicates in Raw expression values).\n")
        }
        if(length(object@a.ctr) != 0) {
           cat("\ta.ctr\t(Control values).\n")
        }
        if(length(object@sd.ctr) != 0) {
           cat("\tsd.ctr\t(Standard Deviation on Raw expression values).\n")
        }
        if(length(object@se.ctr) != 0) {
           cat("\tse.ctr\t(Standard Error on Raw expression values).\n")
        }
        if(length(object@n.ctr) != 0) {
           cat("\tn.ctr\t(Number of replicates in Raw expression values).\n")
        }
    }
)

==> GeneSpring_2.16.0.tar.gz: GeneSpring/R/GSint.R <==
######################################################################################################
#
# GSint CLASS definition
#
# this is the GSint class definition for the GeneSpring Interpretation class
#  and includes a constructor fucntion GSint()
#
# Last update: 16-Feb-2005
# Added the "genenames" slot to represent the names of the genes, in stead of using the rownames
#
# SLOTS
# -----
# expName:   Experiment name
# a.nor:     Matrix representing the AVERAGE expression values for the NORMALIZED expression values
# se.nor:    Matrix representing the STANDARD ERROR for the NORMALIZED expression values
# sd.nor:    Matrix representing the STANDARD DEVIATION for the NORMALIZED expression values
# n.nor:     Matrix representing the NUMBER OF REPLICATES in this condition for the NORMALIZED values
# a.raw:     Matrix representing the AVERAGE expression values for the RAW expression values
# se.raw:    Matrix representing the STANDARD ERROR for the NORMALIZED expression values
# sd.raw:    Matrix representing the STANDARD DEVIATION for the NORMALIZED expression values
# n.raw:     Matrix representing the NUMBER OF REPLICATES in this condition for the NORMALIZED values
# a.ctr:     Matrix representing the AVERAGE expression values for the RAW expression values
# se.ctr:    Matrix representing the STANDARD ERROR for the NORMALIZED expression values
# sd.ctr:    Matrix representing the STANDARD DEVIATION for the NORMALIZED expression values
# n.ctr:     Matrix representing the NUMBER OF REPLICATES in this condition for the NORMALIZED values
# expparam:  Data drame representin the sample attributes or experimental parameters
# numConditions: numeric value representing the number of conditions in this experiment
# ngenes:    Numeric values representing the number of conditions in this experiment
# genenames: List of the names of the genes
#
######################################################################################################

library(methods)

setClass("GSint",
    representation(
        expName = "character",
        a.nor = "matrix",
        se.nor = "matrix",
        sd.nor = "matrix",
        n.nor = "matrix",
        a.raw = "matrix",
        se.raw = "matrix",
        sd.raw = "matrix",
        n.raw = "matrix",
        a.ctr = "matrix",
        se.ctr = "matrix",
        sd.ctr = "matrix",
        n.ctr = "matrix",
        expparam = "data.frame",
        numConditions = "numeric",
        ngenes = "numeric",
        genenames = "character"
    ),
    prototype(
        expName = "GeneSpring experiment",
        a.nor = matrix(nc=0,nr=0),
        se.nor = matrix(nc=0,nr=0),
        sd.nor = matrix(nc=0,nr=0),
        n.nor = matrix(nc=0,nr=0),
        a.raw = matrix(nc=0,nr=0),
        se.raw = matrix(nc=0,nr=0),
        sd.raw = matrix(nc=0,nr=0),
        n.raw = matrix(nc=0,nr=0),
        a.ctr = matrix(nc=0,nr=0),
        se.ctr = matrix(nc=0,nr=0),
        sd.ctr = matrix(nc=0,nr=0),
        n.ctr = matrix(nc=0,nr=0),
        expparam = data.frame(),
        numConditions = 0,
        ngenes = 0,
        genenames = c("")
    )
)


"GSint" <-
function(
             expName = "GeneSpring experiment",
             a.nor = matrix(nc=0,nr=0),
             se.nor = matrix(nc=0,nr=0),
             sd.nor = matrix(nc=0,nr=0),
             n.nor = matrix(nc=0,nr=0),
             a.raw = matrix(nc=0,nr=0),
             se.raw = matrix(nc=0,nr=0),
             sd.raw = matrix(nc=0,nr=0),
             n.raw = matrix(nc=0,nr=0),
             a.ctr = matrix(nc=0,nr=0),
             se.ctr = matrix(nc=0,nr=0),
             sd.ctr = matrix(nc=0,nr=0),
             n.ctr = matrix(nc=0,nr=0),
             expparam = data.frame(),
             numConditions = 0,
             ngenes = 0,
             genenames = c("")
         ) {
         
         if(numConditions == 0) numConditions<-dim(expparam)[2]
         if(ngenes == 0) ngenes<-max(dim(a.nor)[1],dim(se.nor)[1],dim(sd.nor)[1],dim(se.nor)[1],dim(n.nor)[1],dim(a.raw)[1],dim(se.raw)[1],dim(sd.nor)[1],dim(n.nor)[1],dim(a.ctr)[1],dim(se.ctr)[1],dim(n.ctr)[1])

         if(ngenes != length(genenames)) warning("\"ngenes\" does not correspond with number of genes in \"genenames\".")
         if(numConditions>1) if(ngenes != max(dim(a.nor)[1],dim(se.nor)[1],dim(sd.nor)[1],dim(se.nor)[1],dim(n.nor)[1],dim(a.raw)[1],
                          dim(se.raw)[1],dim(sd.nor)[1],dim(n.nor)[1],dim(a.ctr)[1],dim(se.ctr)[1],dim(n.ctr)[1])) warning("\"ngenes\" does not correspond with maximum number of genes in the data matrices")


         library(methods)

         new("GSint",
             expName = expName,
             a.nor = as.matrix(a.nor),
             se.nor = as.matrix(se.nor),
             sd.nor = as.matrix(sd.nor),
             n.nor = as.matrix(n.nor),
             a.raw = as.matrix(a.raw),
             se.raw = as.matrix(se.raw),
             sd.raw = as.matrix(sd.raw),
             n.raw = as.matrix(n.raw),
             a.ctr = as.matrix(a.ctr),
             se.ctr = as.matrix(se.ctr),
             sd.ctr = as.matrix(sd.ctr),
             n.ctr = as.matrix(n.ctr),
             expparam = as.data.frame(expparam),
             numConditions = as.numeric(numConditions),
             ngenes = as.numeric(ngenes),
             genenames = as.character(genenames)
         )
}

setMethod("show", "GSint",
    function(object ) {
        cat("GeneSpring Expression Interpretation set (GSint)\n\t","\"",object@expName,"\" (slot: expName)\n\twith ",
             object@ngenes," genes (slot: ngenes),\n\t",object@numConditions,
             " Conditions/samples (slot: numConditions)\n\tand ",
             dim(object@expparam)[1]," experimental parameters (slot: expparam).\n",sep="")
        cat("Available expression data slots:\n")
        if(length(object@a.nor) != 0) {
           cat("\ta.nor\t(Normalized expression values).\n")
        }
        if(length(object@sd.nor) != 0) {
           cat("\tsd.nor\t(Standard Deviation on Normalized expression values).\n")
        }
        if(length(object@se.nor) != 0) {
           cat("\tse.nor\t(Standard Error on Normalized expression values).\n")
        }
        if(length(object@n.nor) != 0) {
           cat("\tn.nor\t(Number of replicates in Normalized expression values).\n")
        }
        if(length(object@a.raw) != 0) {
           cat("\ta.raw\t(Raw expression values).\n")
        }
        if(length(object@sd.raw) != 0) {
           cat("\tsd.raw\t(Standard Deviation on Raw expression values).\n")
        }
        if(length(object@se.raw) != 0) {
           cat("\tse.raw\t(Standard Error on Raw expression values).\n")
        }
        if(length(object@n.raw) != 0) {
           cat("\tn.raw\t(Number of replicates in Raw expression values).\n")
        }
        if(length(object@a.ctr) != 0) {
           cat("\ta.ctr\t(Control values).\n")
        }
        if(length(object@sd.ctr) != 0) {
           cat("\tsd.ctr\t(Standard Deviation on Raw expression values).\n")
        }
        if(length(object@se.ctr) != 0) {
           cat("\tse.ctr\t(Standard Error on Raw expression values).\n")
        }
        if(length(object@n.ctr) != 0) {
           cat("\tn.ctr\t(Number of replicates in Raw expression values).\n")
        }
    }
)
